@@ -100,8 +100,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from ._jsii import *
 
@@ -119,12 +119,12 @@ class CloudFrontToS3(
     def __init__(
         self,
         scope: aws_cdk.core.Construct,
-        id: str,
+        id: builtins.str,
         *,
         bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         cloud_front_distribution_props: typing.Any = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
-        insert_http_security_headers: typing.Optional[bool] = None,
+        insert_http_security_headers: typing.Optional[builtins.bool] = None,
     ) -> None:
         """
         :param scope: - represents the scope for all the resources.
@@ -150,31 +150,31 @@ class CloudFrontToS3(
 
         jsii.create(CloudFrontToS3, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cloudFrontWebDistribution")
     def cloud_front_web_distribution(
         self,
     ) -> aws_cdk.aws_cloudfront.CloudFrontWebDistribution:
         return jsii.get(self, "cloudFrontWebDistribution")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cloudFrontLoggingBucket")
     def cloud_front_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return jsii.get(self, "cloudFrontLoggingBucket")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="edgeLambdaFunctionVersion")
     def edge_lambda_function_version(
         self,
     ) -> typing.Optional[aws_cdk.aws_lambda.Version]:
         return jsii.get(self, "edgeLambdaFunctionVersion")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="s3Bucket")
     def s3_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return jsii.get(self, "s3Bucket")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="s3LoggingBucket")
     def s3_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return jsii.get(self, "s3LoggingBucket")
@@ -197,7 +197,7 @@ class CloudFrontToS3Props:
         bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         cloud_front_distribution_props: typing.Any = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
-        insert_http_security_headers: typing.Optional[bool] = None,
+        insert_http_security_headers: typing.Optional[builtins.bool] = None,
     ) -> None:
         """
         :param bucket_props: User provided props to override the default props for the S3 Bucket. Default: - Default props are used
@@ -210,7 +210,7 @@ class CloudFrontToS3Props:
         """
         if isinstance(bucket_props, dict):
             bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if bucket_props is not None:
             self._values["bucket_props"] = bucket_props
         if cloud_front_distribution_props is not None:
@@ -227,7 +227,8 @@ class CloudFrontToS3Props:
         default
         :default: - Default props are used
         """
-        return self._values.get("bucket_props")
+        result = self._values.get("bucket_props")
+        return result
 
     @builtins.property
     def cloud_front_distribution_props(self) -> typing.Any:
@@ -236,7 +237,8 @@ class CloudFrontToS3Props:
         default
         :default: - Default props are used
         """
-        return self._values.get("cloud_front_distribution_props")
+        result = self._values.get("cloud_front_distribution_props")
+        return result
 
     @builtins.property
     def existing_bucket_obj(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
@@ -245,21 +247,23 @@ class CloudFrontToS3Props:
         default
         :default: - None
         """
-        return self._values.get("existing_bucket_obj")
+        result = self._values.get("existing_bucket_obj")
+        return result
 
     @builtins.property
-    def insert_http_security_headers(self) -> typing.Optional[bool]:
+    def insert_http_security_headers(self) -> typing.Optional[builtins.bool]:
         """Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront.
 
         default
         :default: - true
         """
-        return self._values.get("insert_http_security_headers")
+        result = self._values.get("insert_http_security_headers")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
